pub(crate) enum Action {
Loading,
Storing,
Deleting,
Locking,
Unlocking,
Initializing,
Enumerating,
}Expand description
An action that we were trying to perform when an error occurred.
Variants
Loading
We were trying to load an element from the store.
Storing
We were trying to save an element into the store.
Deleting
We were trying to remove an element from the store.
Locking
We were trying to acquire the lock for the store.
Unlocking
We were trying to release the lock for the store.
Initializing
We were trying to validate the storage and initialize the manager.
Enumerating
We were trying to enumerate state objects