pub(super) fn files_to_delete(statepath: &Path, now: SystemTime) -> Vec<PathBuf>Expand description
Implementation helper for FsStateMgr::clean():
list all files in statepath that are ready to delete as of now.
pub(super) fn files_to_delete(statepath: &Path, now: SystemTime) -> Vec<PathBuf>Implementation helper for FsStateMgr::clean():
list all files in statepath that are ready to delete as of now.