struct FsStateMgrInner {
statepath: CheckedDir,
lockfile: Mutex<LockFile>,
lock_dropped_tx: Sender<Void>,
lock_dropped_rx: Shared<Receiver<Void>>,
}Expand description
Inner reference-counted object, used by FsStateMgr.
Fields
statepath: CheckedDirDirectory in which we store state files.
lockfile: Mutex<LockFile>Lockfile to achieve exclusive access to state files.
lock_dropped_tx: Sender<Void>A oneshot sender that is used to alert other tasks when this lock is finally dropped.
It is a sender for Void because we never actually want to send anything here; we only want to generate canceled events.
lock_dropped_rx: Shared<Receiver<Void>>Cloneable handle which resolves when this lock is dropped.