pub(crate) struct StorageHandleImpl<M, T> {
mgr: M,
key: String,
phantom: PhantomData<fn(T) -> T>,
}Expand description
Concrete implementation of StorageHandle.
Fields
mgr: MAn underlying StateMgr to use.
The type M should probably implement Clone, since we store it
here and don’t give it back.
key: StringThe key to use when loading and storing from the StateMgr.
phantom: PhantomData<fn(T) -> T>A zero-sized type to please the type checker, which will otherwise complain about the absence of anything in the struct that uses T.
This uses fn(T) -> T to ensure that the type T is mentioned and
has the correct variance, without forcing this type to have
the same Send/Sync status as T.
Implementations
Sourceimpl<M, T> StorageHandleImpl<M, T>
impl<M, T> StorageHandleImpl<M, T>
Sourcepub(crate) fn new(mgr: M, key: String) -> StorageHandleImpl<M, T>
pub(crate) fn new(mgr: M, key: String) -> StorageHandleImpl<M, T>
Construct a new StorageHandleImpl.