pub(crate) struct Target<'r> {
pub(crate) dir: &'r CheckedDir,
pub(crate) rel_fname: &'r Path,
}Expand description
Common arguments to load/store operations
Fields
dir: &'r CheckedDirDirectory
rel_fname: &'r PathFilename relative to dir
Might be a leafname; must be relative
Should include the .json extension.
Implementations
Sourceimpl Target<'_>
impl Target<'_>
Sourcepub(crate) fn load<D: DeserializeOwned>(&self) -> Result<Option<D>, ErrorSource>
pub(crate) fn load<D: DeserializeOwned>(&self) -> Result<Option<D>, ErrorSource>
Load and deserialize a D from the file specified by self
Returns None if the file doesn’t exist.
Sourcepub(crate) fn store<S: Serialize>(&self, val: &S) -> Result<(), ErrorSource>
pub(crate) fn store<S: Serialize>(&self, val: &S) -> Result<(), ErrorSource>
Serialise and store an S to the file specified by self
Concurrent readers (using load) will see either the old data,
or the new data,
not corruption or a mixture.
Likewise, if something fails, the old data will remain.
(But, we do not use fsync.)
It is a serious bug to make several concurrent calls to store
for the same file.
That might result in corrupted files.
See fs_mistrust::CheckedDir::write_and_replace
for more details about the semantics.
Sourcepub(crate) fn delete(&self) -> Result<(), ErrorSource>
pub(crate) fn delete(&self) -> Result<(), ErrorSource>
Delete the file specified by self