fn touch_instance_dir(dir: &CheckedDir) -> Result<()>Expand description
Touch an instance the state directory, dir, for expiry purposes
fn touch_instance_dir(dir: &CheckedDir) -> Result<()>Touch an instance the state directory, dir, for expiry purposes