pub struct StorageHandle<T> {
instance_dir: CheckedDir,
leafname: String,
marker: PhantomData<fn(T) -> T>,
flock_guard: Arc<LockFileGuard>,
}Expand description
A place in the state or cache directory, where we can load/store a serialisable type
Implies exclusive access.
Rust mutability-xor-sharing rules enforce proper synchronisation,
unless multiple StorageHandles are created
using the same InstanceStateHandle and key.
Fields
instance_dir: CheckedDirThe directory and leafname
leafname: StringKEY.json
marker: PhantomData<fn(T) -> T>We can load and store a T.
Invariant in T. But we’re Sync and Send regardless of T.
(From the Table of PhantomData patterns in the Nomicon.)
flock_guard: Arc<LockFileGuard>Clone of the InstanceStateHandle’s lock
Implementations
Sourceimpl<T: Serialize + DeserializeOwned> StorageHandle<T>
impl<T: Serialize + DeserializeOwned> StorageHandle<T>
Sourcepub fn load(&self) -> Result<Option<T>>
pub fn load(&self) -> Result<Option<T>>
Load this persistent state
None means the state was most recently deleteed
Sourcefn with_load_store_target<R, F>(&self, action: Action, f: F) -> Result<R>
fn with_load_store_target<R, F>(&self, action: Action, f: F) -> Result<R>
Operate using a load_store::Target
Sourcefn map_err(&self, action: Action) -> impl FnOnce(ErrorSource) -> Error + use<T>
fn map_err(&self, action: Action) -> impl FnOnce(ErrorSource) -> Error + use<T>
Helper to convert an ErrorSource to an Error, if we were performing action
Sourcefn err_resource(&self) -> Resource
fn err_resource(&self) -> Resource
Return the proper Resource for reporting errors