pub trait FsMistrustErrorExt: Sealed {
// Required methods
fn cache_error_kind(&self) -> ErrorKind;
fn state_error_kind(&self) -> ErrorKind;
fn keystore_error_kind(&self) -> ErrorKind;
}Expand description
Extension trait for getting a tor_error::ErrorKind from a fs_mistrust::Error
Required Methods
Sourcefn cache_error_kind(&self) -> ErrorKind
fn cache_error_kind(&self) -> ErrorKind
The error kind if we were trying to accessa cache directory
Sourcefn state_error_kind(&self) -> ErrorKind
fn state_error_kind(&self) -> ErrorKind
The error kind if we were trying to accessa persistent state directory
Sourcefn keystore_error_kind(&self) -> ErrorKind
fn keystore_error_kind(&self) -> ErrorKind
The error kind if we were trying to accessa keystore
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl FsMistrustErrorExt for Error
Extension trait for getting a tor_error::ErrorKind from a fs_mistrust::Error
impl FsMistrustErrorExt for Error
Extension trait for getting a tor_error::ErrorKind from a fs_mistrust::Error
Sourcefn cache_error_kind(&self) -> ErrorKind
fn cache_error_kind(&self) -> ErrorKind
The error kind if we were trying to accessa cache directory
Sourcefn state_error_kind(&self) -> ErrorKind
fn state_error_kind(&self) -> ErrorKind
The error kind if we were trying to accessa persistent state directory
Sourcefn keystore_error_kind(&self) -> ErrorKind
fn keystore_error_kind(&self) -> ErrorKind
The error kind if we were trying to accessa keystore